Special Functions
=================

.. https://docs.scipy.org/doc/scipy/reference/special.html

Bessel Functions
----------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupyx.scipy.special.j0
   cupyx.scipy.special.j1
   cupyx.scipy.special.y0
   cupyx.scipy.special.y1
   cupyx.scipy.special.i0
   cupyx.scipy.special.i1


Gamma and Related Functions
---------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupyx.scipy.special.gamma
   cupyx.scipy.special.gammaln
   cupyx.scipy.special.polygamma
   cupyx.scipy.special.digamma


Raw Statistical Functions
-------------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupyx.scipy.special.ndtr


Error Function
--------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupyx.scipy.special.erf
   cupyx.scipy.special.erfc
   cupyx.scipy.special.erfcx
   cupyx.scipy.special.erfinv
   cupyx.scipy.special.erfcinv


Other Special Functions
-----------------------

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupyx.scipy.special.zeta
